==> ibiz-model-8.1.0.304-sources.jar: net/ibizsys/model/app/view/PSAppViewMsgImpl.java <==
package net.ibizsys.model.app.view;



public class PSAppViewMsgImpl extends net.ibizsys.model.app.PSApplicationObjectImpl implements net.ibizsys.model.app.view.IPSAppViewMsg{

	public final static String ATTR_GETCODENAME = "codeName";
	public final static String ATTR_GETCONTENTPSLANGUAGERES = "getContentPSLanguageRes";
	public final static String ATTR_GETDYNAMODELFILEPATH = "dynaModelFilePath";
	public final static String ATTR_GETDYNAMICMODE = "dynamicMode";
	public final static String ATTR_GETMESSAGE = "message";
	public final static String ATTR_GETMESSAGETYPE = "messageType";
	public final static String ATTR_GETORDERVALUE = "orderValue";
	public final static String ATTR_GETPSAPPMSGTEMPL = "getPSAppMsgTempl";
	public final static String ATTR_GETPOSITION = "position";
	public final static String ATTR_GETREMOVEMODE = "removeMode";
	public final static String ATTR_GETTITLE = "title";
	public final static String ATTR_GETTITLELANRESTAG = "titleLanResTag";
	public final static String ATTR_GETTITLEPSLANGUAGERES = "getTitlePSLanguageRes";
	public final static String ATTR_ISENABLEREMOVE = "enableRemove";

	public java.lang.String getCodeName(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETCODENAME);
		if(value == null){
			return null;
		}
		return value.asText();
	}
	private net.ibizsys.model.res.IPSLanguageRes contentpslanguageres;

	public net.ibizsys.model.res.IPSLanguageRes getContentPSLanguageRes(){
		if(this.contentpslanguageres != null) return this.contentpslanguageres;
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETCONTENTPSLANGUAGERES);
		if(value == null){
			return null;
		}
		this.contentpslanguageres = getPSModelObject(net.ibizsys.model.res.IPSLanguageRes.class, (com.fasterxml.jackson.databind.node.ObjectNode)value, ATTR_GETCONTENTPSLANGUAGERES);
		return this.contentpslanguageres;
	}

	public net.ibizsys.model.res.IPSLanguageRes getContentPSLanguageResMust(){
		net.ibizsys.model.res.IPSLanguageRes value = this.getContentPSLanguageRes();
		if(value == null){throw new net.ibizsys.model.PSModelException(this, "未指定内容多语言资源对象");}
		return value;
	}


	@Deprecated
	public java.lang.String getDynaModelFilePath(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETDYNAMODELFILEPATH);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public int getDynamicMode(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETDYNAMICMODE);
		if(value == null){
			return 0;
		}
		return value.asInt();
	}

	public java.lang.String getMessage(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETMESSAGE);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public java.lang.String getMessageType(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETMESSAGETYPE);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	@Deprecated
	public int getOrderValue(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETORDERVALUE);
		if(value == null){
			return 0;
		}
		return value.asInt();
	}
	private net.ibizsys.model.app.msg.IPSAppMsgTempl psappmsgtempl;

	public net.ibizsys.model.app.msg.IPSAppMsgTempl getPSAppMsgTempl(){
		if(this.psappmsgtempl != null) return this.psappmsgtempl;
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETPSAPPMSGTEMPL);
		if(value == null){
			return null;
		}
		net.ibizsys.model.app.IPSApplication ipsapplication = getParentPSModelObject(net.ibizsys.model.app.IPSApplication.class);
		this.psappmsgtempl = ipsapplication.getPSAppMsgTempl(value, false);
		return this.psappmsgtempl;
	}

	public net.ibizsys.model.app.msg.IPSAppMsgTempl getPSAppMsgTemplMust(){
		net.ibizsys.model.app.msg.IPSAppMsgTempl value = this.getPSAppMsgTempl();
		if(value == null){throw new net.ibizsys.model.PSModelException(this, "未指定应用消息模板");}
		return value;
	}


	public java.lang.String getPosition(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETPOSITION);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public int getRemoveMode(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETREMOVEMODE);
		if(value == null){
			return 0;
		}
		return value.asInt();
	}

	public java.lang.String getTitle(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETTITLE);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public java.lang.String getTitleLanResTag(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETTITLELANRESTAG);
		if(value == null){
			return null;
		}
		return value.asText();
	}
	private net.ibizsys.model.res.IPSLanguageRes titlepslanguageres;

	public net.ibizsys.model.res.IPSLanguageRes getTitlePSLanguageRes(){
		if(this.titlepslanguageres != null) return this.titlepslanguageres;
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETTITLEPSLANGUAGERES);
		if(value == null){
			return null;
		}
		this.titlepslanguageres = getPSModelObject(net.ibizsys.model.res.IPSLanguageRes.class, (com.fasterxml.jackson.databind.node.ObjectNode)value, ATTR_GETTITLEPSLANGUAGERES);
		return this.titlepslanguageres;
	}

	public net.ibizsys.model.res.IPSLanguageRes getTitlePSLanguageResMust(){
		net.ibizsys.model.res.IPSLanguageRes value = this.getTitlePSLanguageRes();
		if(value == null){throw new net.ibizsys.model.PSModelException(this, "未指定抬头语言资源对象");}
		return value;
	}


	public boolean isEnableRemove(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_ISENABLEREMOVE);
		if(value == null){
			return false;
		}
		return value.asBoolean();
	}
}

==> ibiz-model-8.1.0.465-sources.jar: net/ibizsys/model/app/view/PSAppViewMsgImpl.java <==
package net.ibizsys.model.app.view;



public class PSAppViewMsgImpl extends net.ibizsys.model.app.PSApplicationObjectImpl implements net.ibizsys.model.app.view.IPSAppViewMsg{

	public final static String ATTR_GETCODENAME = "codeName";
	public final static String ATTR_GETCONTENTPSLANGUAGERES = "getContentPSLanguageRes";
	public final static String ATTR_GETDYNAMODELFILEPATH = "dynaModelFilePath";
	public final static String ATTR_GETDYNAMICMODE = "dynamicMode";
	public final static String ATTR_GETMESSAGE = "message";
	public final static String ATTR_GETMESSAGETYPE = "messageType";
	public final static String ATTR_GETORDERVALUE = "orderValue";
	public final static String ATTR_GETPSAPPMSGTEMPL = "getPSAppMsgTempl";
	public final static String ATTR_GETPOSITION = "position";
	public final static String ATTR_GETREMOVEMODE = "removeMode";
	public final static String ATTR_GETTITLE = "title";
	public final static String ATTR_GETTITLELANRESTAG = "titleLanResTag";
	public final static String ATTR_GETTITLEPSLANGUAGERES = "getTitlePSLanguageRes";
	public final static String ATTR_GETUNIQUETAG = "uniqueTag";
	public final static String ATTR_ISENABLEREMOVE = "enableRemove";

	public java.lang.String getCodeName(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETCODENAME);
		if(value == null){
			return null;
		}
		return value.asText();
	}
	private net.ibizsys.model.res.IPSLanguageRes contentpslanguageres;

	public net.ibizsys.model.res.IPSLanguageRes getContentPSLanguageRes(){
		if(this.contentpslanguageres != null) return this.contentpslanguageres;
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETCONTENTPSLANGUAGERES);
		if(value == null){
			return null;
		}
		this.contentpslanguageres = getPSModelObject(net.ibizsys.model.res.IPSLanguageRes.class, (com.fasterxml.jackson.databind.node.ObjectNode)value, ATTR_GETCONTENTPSLANGUAGERES);
		return this.contentpslanguageres;
	}

	public net.ibizsys.model.res.IPSLanguageRes getContentPSLanguageResMust(){
		net.ibizsys.model.res.IPSLanguageRes value = this.getContentPSLanguageRes();
		if(value == null){throw new net.ibizsys.model.PSModelException(this, "未指定内容多语言资源对象");}
		return value;
	}


	@Deprecated
	public java.lang.String getDynaModelFilePath(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETDYNAMODELFILEPATH);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public int getDynamicMode(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETDYNAMICMODE);
		if(value == null){
			return 0;
		}
		return value.asInt();
	}

	public java.lang.String getMessage(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETMESSAGE);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public java.lang.String getMessageType(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETMESSAGETYPE);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	@Deprecated
	public int getOrderValue(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETORDERVALUE);
		if(value == null){
			return 0;
		}
		return value.asInt();
	}
	private net.ibizsys.model.app.msg.IPSAppMsgTempl psappmsgtempl;

	public net.ibizsys.model.app.msg.IPSAppMsgTempl getPSAppMsgTempl(){
		if(this.psappmsgtempl != null) return this.psappmsgtempl;
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETPSAPPMSGTEMPL);
		if(value == null){
			return null;
		}
		net.ibizsys.model.app.IPSApplication ipsapplication = getParentPSModelObject(net.ibizsys.model.app.IPSApplication.class);
		this.psappmsgtempl = ipsapplication.getPSAppMsgTempl(value, false);
		return this.psappmsgtempl;
	}

	public net.ibizsys.model.app.msg.IPSAppMsgTempl getPSAppMsgTemplMust(){
		net.ibizsys.model.app.msg.IPSAppMsgTempl value = this.getPSAppMsgTempl();
		if(value == null){throw new net.ibizsys.model.PSModelException(this, "未指定应用消息模板");}
		return value;
	}


	public java.lang.String getPosition(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETPOSITION);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public int getRemoveMode(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETREMOVEMODE);
		if(value == null){
			return 0;
		}
		return value.asInt();
	}

	public java.lang.String getTitle(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETTITLE);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public java.lang.String getTitleLanResTag(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETTITLELANRESTAG);
		if(value == null){
			return null;
		}
		return value.asText();
	}
	private net.ibizsys.model.res.IPSLanguageRes titlepslanguageres;

	public net.ibizsys.model.res.IPSLanguageRes getTitlePSLanguageRes(){
		if(this.titlepslanguageres != null) return this.titlepslanguageres;
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETTITLEPSLANGUAGERES);
		if(value == null){
			return null;
		}
		this.titlepslanguageres = getPSModelObject(net.ibizsys.model.res.IPSLanguageRes.class, (com.fasterxml.jackson.databind.node.ObjectNode)value, ATTR_GETTITLEPSLANGUAGERES);
		return this.titlepslanguageres;
	}

	public net.ibizsys.model.res.IPSLanguageRes getTitlePSLanguageResMust(){
		net.ibizsys.model.res.IPSLanguageRes value = this.getTitlePSLanguageRes();
		if(value == null){throw new net.ibizsys.model.PSModelException(this, "未指定抬头语言资源对象");}
		return value;
	}


	public java.lang.String getUniqueTag(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETUNIQUETAG);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public boolean isEnableRemove(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_ISENABLEREMOVE);
		if(value == null){
			return false;
		}
		return value.asBoolean();
	}
}
